/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.options;

import org.pepstock.charba.client.AbstractChart;
import org.pepstock.charba.client.commons.Key;

/**
 * Configuration of chart with multiple scales.
 * 
 * @author Andrea "Stock" Stocchero
 *
 */
public abstract class MultiScalesOptions extends BaseOptions {

	private final Scales scales;

	/**
	 * Name of fields of JavaScript object.
	 */
	private enum Property implements Key
	{
		scales
	}

	/**
	 * Builds the object storing the chart instance.<br>
	 * Sets also the scales object.
	 * 
	 * @param chart chart instance
	 */
	protected MultiScalesOptions(AbstractChart<?, ?> chart) {
		super(chart);
		scales = new Scales(chart);
		setValue(Property.scales, scales);
	}

	/**
	 * @return the scales
	 */
	public Scales getScales() {
		return scales;
	}

}